==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24BevelBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$BevelBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 841e9def39bee722 javax_swing_border_BevelBorder
// @dep_class 238ea4885f38342d javax_swing_plaf_BorderUIResource__24BevelBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_BevelBorder

#include "javax/swing/border/BevelBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint);
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_BevelBorder$vmethods	javax_swing_border_BevelBorder;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
    _jc_javax_swing_border_BevelBorder$sub_refs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_BevelBorder$sub_nonrefs	javax_swing_border_BevelBorder;
    _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24BevelBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24BevelBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$BevelBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 841e9def39bee722 javax_swing_border_BevelBorder
// @dep_class 238ea4885f38342d javax_swing_plaf_BorderUIResource__24BevelBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_BevelBorder

#include "javax/swing/border/BevelBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_BevelBorder$vmethods	javax_swing_border_BevelBorder;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
    _jc_javax_swing_border_BevelBorder$sub_refs	javax_swing_border_BevelBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_BevelBorder$sub_nonrefs	javax_swing_border_BevelBorder;
    _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24BevelBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24BevelBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24BevelBorderUIResource_H_ */
